pub struct DeviceConfigConfigManagerImageRegistrySecret {
pub name: Option<String>,
}Expand description
config manager image registry secret used to pull/push images
Fields
name: Option<String>Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names