pub struct DeviceConfigMetricsExporterRbacConfigClientCaConfigMap {
pub name: Option<String>,
}Expand description
Reference to a configmap containing the client CA (key: ca.crt) for mTLS client validation
Fields
name: Option<String>Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names