pub struct DeviceConfigStatusDriver {
pub available_number: Option<i32>,
pub desired_number: Option<i32>,
pub nodes_matching_selector_number: Option<i32>,
}Expand description
Driver contains the status of the Drivers deployment
Fields
available_number: Option<i32>number of the actually deployed and running pods
desired_number: Option<i32>number of the pods that should be deployed for daemonset
nodes_matching_selector_number: Option<i32>number of nodes that are targeted by the DeviceConfig selector